@@ -2,6 +2,7 @@ from pathlib import Path
 from typing import Union, List, Dict
 
 from .deal_json import load_json_from_url
+from .config import config
 
 path = Path.cwd() / "data" / "genshin_history"
 
@@ -15,11 +16,7 @@ async def get_info_from_url(
     :return: Union[dict, list[dict]]
     """
     cache_dir.mkdir(parents=True, exist_ok=True)
-    url = (
-        "https://genshin-gacha-banners.52v6.com/data/character.json"
-        if cha
-        else "https://genshin-gacha-banners.52v6.com/data/weapon.json"
-    )
+    url = f"https://{config.gshisbanner_json_url}/data/{'character' if cha else 'weapon'}.json"
     cache_path = cache_dir / ("character.json" if cha else "weapon.json")
     return await load_json_from_url(url, path=cache_path)
 
